Resource

Trait Resource 

pub trait Resource {
    type Scope: ResourceScope;

    const API_VERSION: &'static str;
    const GROUP: &'static str;
    const KIND: &'static str;
    const VERSION: &'static str;
    const URL_PATH_SEGMENT: &'static str;
}
A trait applied to all Kubernetes resources.

Required Associated Constants

const API_VERSION: &'static str

The API version of the resource. This is a composite of Resource::GROUP and Resource::VERSION (eg "apiextensions.k8s.io/v1beta1") or just the version for resources without a group (eg "v1").

This is the string used in the apiVersion field of the resource’s serialized form.

const GROUP: &'static str

The group of the resource, or the empty string if the resource doesn’t have a group.

const KIND: &'static str

The kind of the resource.

This is the string used in the kind field of the resource’s serialized form.

const VERSION: &'static str

The version of the resource.

const URL_PATH_SEGMENT: &'static str

The URL path segment used to construct URLs related to this resource.

For cluster- and namespaced-scoped resources, this is the plural name of the resource that is followed by the resource name. For example, api::core::v1::Pod’s value is "pods" and its URLs look like .../pods/{name}.

For subresources, this is the subresource name that comes after the parent resource’s name. For example, api::authentication::v1::TokenRequest’s value is "token", and its URLs look like .../serviceaccounts/{name}/token.

Required Associated Types

type Scope: ResourceScope

Indicates whether the resource is namespace-scoped or cluster-scoped or a subresource.

If you need to restrict some generic code to resources of a specific scope, use this associated type to create a bound on the generic. For example, fn foo<T: k8s_openapi::Resource<Scope = k8s_openapi::ClusterResourceScope>>() { } can only be called with cluster-scoped resources.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Resource for APIGroup

Source

const API_VERSION: &'static str = "v1"

Source

const GROUP: &'static str = ""

Source

const KIND: &'static str = "APIGroup"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = ""

Source

type Scope = ClusterResourceScope

Source

impl Resource for APIGroupList

Source

const API_VERSION: &'static str = "v1"

Source

const GROUP: &'static str = ""

Source

const KIND: &'static str = "APIGroupList"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = ""

Source

type Scope = ClusterResourceScope

Source

impl Resource for APIResourceList

Source

const API_VERSION: &'static str = "v1"

Source

const GROUP: &'static str = ""

Source

const KIND: &'static str = "APIResourceList"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = ""

Source

type Scope = ClusterResourceScope

Source

impl Resource for APIService

Source

const API_VERSION: &'static str = "apiregistration.k8s.io/v1"

Source

const GROUP: &'static str = "apiregistration.k8s.io"

Source

const KIND: &'static str = "APIService"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "apiservices"

Source

type Scope = ClusterResourceScope

Source

impl Resource for APIVersions

Source

const API_VERSION: &'static str = "v1"

Source

const GROUP: &'static str = ""

Source

const KIND: &'static str = "APIVersions"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = ""

Source

type Scope = ClusterResourceScope

Source

impl Resource for Binding

Source

const API_VERSION: &'static str = "v1"

Source

const GROUP: &'static str = ""

Source

const KIND: &'static str = "Binding"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "bindings"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for CSIDriver

Source

const API_VERSION: &'static str = "storage.k8s.io/v1"

Source

const GROUP: &'static str = "storage.k8s.io"

Source

const KIND: &'static str = "CSIDriver"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "csidrivers"

Source

type Scope = ClusterResourceScope

Source

impl Resource for CSINode

Source

const API_VERSION: &'static str = "storage.k8s.io/v1"

Source

const GROUP: &'static str = "storage.k8s.io"

Source

const KIND: &'static str = "CSINode"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "csinodes"

Source

type Scope = ClusterResourceScope

Source

impl Resource for CSIStorageCapacity

Source

const API_VERSION: &'static str = "storage.k8s.io/v1"

Source

const GROUP: &'static str = "storage.k8s.io"

Source

const KIND: &'static str = "CSIStorageCapacity"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "csistoragecapacities"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for CertificateSigningRequest

Source

const API_VERSION: &'static str = "certificates.k8s.io/v1"

Source

const GROUP: &'static str = "certificates.k8s.io"

Source

const KIND: &'static str = "CertificateSigningRequest"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "certificatesigningrequests"

Source

type Scope = ClusterResourceScope

Source

impl Resource for ClusterRole

Source

const API_VERSION: &'static str = "rbac.authorization.k8s.io/v1"

Source

const GROUP: &'static str = "rbac.authorization.k8s.io"

Source

const KIND: &'static str = "ClusterRole"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "clusterroles"

Source

type Scope = ClusterResourceScope

Source

impl Resource for ClusterRoleBinding

Source

const API_VERSION: &'static str = "rbac.authorization.k8s.io/v1"

Source

const GROUP: &'static str = "rbac.authorization.k8s.io"

Source

const KIND: &'static str = "ClusterRoleBinding"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "clusterrolebindings"

Source

type Scope = ClusterResourceScope

Source

impl Resource for k8s_openapi::api::certificates::v1alpha1::ClusterTrustBundle

Source

const API_VERSION: &'static str = "certificates.k8s.io/v1alpha1"

Source

const GROUP: &'static str = "certificates.k8s.io"

Source

const KIND: &'static str = "ClusterTrustBundle"

Source

const VERSION: &'static str = "v1alpha1"

Source

const URL_PATH_SEGMENT: &'static str = "clustertrustbundles"

Source

type Scope = ClusterResourceScope

Source

impl Resource for k8s_openapi::api::certificates::v1beta1::ClusterTrustBundle

Source

const API_VERSION: &'static str = "certificates.k8s.io/v1beta1"

Source

const GROUP: &'static str = "certificates.k8s.io"

Source

const KIND: &'static str = "ClusterTrustBundle"

Source

const VERSION: &'static str = "v1beta1"

Source

const URL_PATH_SEGMENT: &'static str = "clustertrustbundles"

Source

type Scope = ClusterResourceScope

Source

impl Resource for ComponentStatus

Source

const API_VERSION: &'static str = "v1"

Source

const GROUP: &'static str = ""

Source

const KIND: &'static str = "ComponentStatus"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "componentstatuses"

Source

type Scope = ClusterResourceScope

Source

impl Resource for ConfigMap

Source

const API_VERSION: &'static str = "v1"

Source

const GROUP: &'static str = ""

Source

const KIND: &'static str = "ConfigMap"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "configmaps"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for ControllerRevision

Source

const API_VERSION: &'static str = "apps/v1"

Source

const GROUP: &'static str = "apps"

Source

const KIND: &'static str = "ControllerRevision"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "controllerrevisions"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for CronJob

Source

const API_VERSION: &'static str = "batch/v1"

Source

const GROUP: &'static str = "batch"

Source

const KIND: &'static str = "CronJob"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "cronjobs"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for CustomResourceDefinition

Source

const API_VERSION: &'static str = "apiextensions.k8s.io/v1"

Source

const GROUP: &'static str = "apiextensions.k8s.io"

Source

const KIND: &'static str = "CustomResourceDefinition"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "customresourcedefinitions"

Source

type Scope = ClusterResourceScope

Source

impl Resource for DaemonSet

Source

const API_VERSION: &'static str = "apps/v1"

Source

const GROUP: &'static str = "apps"

Source

const KIND: &'static str = "DaemonSet"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "daemonsets"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for Deployment

Source

const API_VERSION: &'static str = "apps/v1"

Source

const GROUP: &'static str = "apps"

Source

const KIND: &'static str = "Deployment"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "deployments"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for k8s_openapi::api::resource::v1::DeviceClass

Source

const API_VERSION: &'static str = "resource.k8s.io/v1"

Source

const GROUP: &'static str = "resource.k8s.io"

Source

const KIND: &'static str = "DeviceClass"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "deviceclasses"

Source

type Scope = ClusterResourceScope

Source

impl Resource for k8s_openapi::api::resource::v1beta1::DeviceClass

Source

const API_VERSION: &'static str = "resource.k8s.io/v1beta1"

Source

const GROUP: &'static str = "resource.k8s.io"

Source

const KIND: &'static str = "DeviceClass"

Source

const VERSION: &'static str = "v1beta1"

Source

const URL_PATH_SEGMENT: &'static str = "deviceclasses"

Source

type Scope = ClusterResourceScope

Source

impl Resource for k8s_openapi::api::resource::v1beta2::DeviceClass

Source

const API_VERSION: &'static str = "resource.k8s.io/v1beta2"

Source

const GROUP: &'static str = "resource.k8s.io"

Source

const KIND: &'static str = "DeviceClass"

Source

const VERSION: &'static str = "v1beta2"

Source

const URL_PATH_SEGMENT: &'static str = "deviceclasses"

Source

type Scope = ClusterResourceScope

Source

impl Resource for k8s_openapi::api::resource::v1alpha3::DeviceTaintRule

Source

const API_VERSION: &'static str = "resource.k8s.io/v1alpha3"

Source

const GROUP: &'static str = "resource.k8s.io"

Source

const KIND: &'static str = "DeviceTaintRule"

Source

const VERSION: &'static str = "v1alpha3"

Source

const URL_PATH_SEGMENT: &'static str = "devicetaintrules"

Source

type Scope = ClusterResourceScope

Source

impl Resource for k8s_openapi::api::resource::v1beta2::DeviceTaintRule

Source

const API_VERSION: &'static str = "resource.k8s.io/v1beta2"

Source

const GROUP: &'static str = "resource.k8s.io"

Source

const KIND: &'static str = "DeviceTaintRule"

Source

const VERSION: &'static str = "v1beta2"

Source

const URL_PATH_SEGMENT: &'static str = "devicetaintrules"

Source

type Scope = ClusterResourceScope

Source

impl Resource for EndpointSlice

Source

const API_VERSION: &'static str = "discovery.k8s.io/v1"

Source

const GROUP: &'static str = "discovery.k8s.io"

Source

const KIND: &'static str = "EndpointSlice"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "endpointslices"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for Endpoints

Source

const API_VERSION: &'static str = "v1"

Source

const GROUP: &'static str = ""

Source

const KIND: &'static str = "Endpoints"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "endpoints"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for k8s_openapi::api::core::v1::Event

Source

const API_VERSION: &'static str = "v1"

Source

const GROUP: &'static str = ""

Source

const KIND: &'static str = "Event"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "events"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for k8s_openapi::api::events::v1::Event

Source

const API_VERSION: &'static str = "events.k8s.io/v1"

Source

const GROUP: &'static str = "events.k8s.io"

Source

const KIND: &'static str = "Event"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "events"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for Eviction

Source

const API_VERSION: &'static str = "policy/v1"

Source

const GROUP: &'static str = "policy"

Source

const KIND: &'static str = "Eviction"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "eviction"

Source

type Scope = SubResourceScope

Source

impl Resource for FlowSchema

Source

const API_VERSION: &'static str = "flowcontrol.apiserver.k8s.io/v1"

Source

const GROUP: &'static str = "flowcontrol.apiserver.k8s.io"

Source

const KIND: &'static str = "FlowSchema"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "flowschemas"

Source

type Scope = ClusterResourceScope

Source

impl Resource for k8s_openapi::api::autoscaling::v1::HorizontalPodAutoscaler

Source

const API_VERSION: &'static str = "autoscaling/v1"

Source

const GROUP: &'static str = "autoscaling"

Source

const KIND: &'static str = "HorizontalPodAutoscaler"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "horizontalpodautoscalers"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for k8s_openapi::api::autoscaling::v2::HorizontalPodAutoscaler

Source

const API_VERSION: &'static str = "autoscaling/v2"

Source

const GROUP: &'static str = "autoscaling"

Source

const KIND: &'static str = "HorizontalPodAutoscaler"

Source

const VERSION: &'static str = "v2"

Source

const URL_PATH_SEGMENT: &'static str = "horizontalpodautoscalers"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for k8s_openapi::api::networking::v1::IPAddress

Source

const API_VERSION: &'static str = "networking.k8s.io/v1"

Source

const GROUP: &'static str = "networking.k8s.io"

Source

const KIND: &'static str = "IPAddress"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "ipaddresses"

Source

type Scope = ClusterResourceScope

Source

impl Resource for k8s_openapi::api::networking::v1beta1::IPAddress

Source

const API_VERSION: &'static str = "networking.k8s.io/v1beta1"

Source

const GROUP: &'static str = "networking.k8s.io"

Source

const KIND: &'static str = "IPAddress"

Source

const VERSION: &'static str = "v1beta1"

Source

const URL_PATH_SEGMENT: &'static str = "ipaddresses"

Source

type Scope = ClusterResourceScope

Source

impl Resource for Ingress

Source

const API_VERSION: &'static str = "networking.k8s.io/v1"

Source

const GROUP: &'static str = "networking.k8s.io"

Source

const KIND: &'static str = "Ingress"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "ingresses"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for IngressClass

Source

const API_VERSION: &'static str = "networking.k8s.io/v1"

Source

const GROUP: &'static str = "networking.k8s.io"

Source

const KIND: &'static str = "IngressClass"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "ingressclasses"

Source

type Scope = ClusterResourceScope

Source

impl Resource for Job

Source

const API_VERSION: &'static str = "batch/v1"

Source

const GROUP: &'static str = "batch"

Source

const KIND: &'static str = "Job"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "jobs"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for Lease

Source

const API_VERSION: &'static str = "coordination.k8s.io/v1"

Source

const GROUP: &'static str = "coordination.k8s.io"

Source

const KIND: &'static str = "Lease"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "leases"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for k8s_openapi::api::coordination::v1alpha2::LeaseCandidate

Source

const API_VERSION: &'static str = "coordination.k8s.io/v1alpha2"

Source

const GROUP: &'static str = "coordination.k8s.io"

Source

const KIND: &'static str = "LeaseCandidate"

Source

const VERSION: &'static str = "v1alpha2"

Source

const URL_PATH_SEGMENT: &'static str = "leasecandidates"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for k8s_openapi::api::coordination::v1beta1::LeaseCandidate

Source

const API_VERSION: &'static str = "coordination.k8s.io/v1beta1"

Source

const GROUP: &'static str = "coordination.k8s.io"

Source

const KIND: &'static str = "LeaseCandidate"

Source

const VERSION: &'static str = "v1beta1"

Source

const URL_PATH_SEGMENT: &'static str = "leasecandidates"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for LimitRange

Source

const API_VERSION: &'static str = "v1"

Source

const GROUP: &'static str = ""

Source

const KIND: &'static str = "LimitRange"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "limitranges"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for LocalSubjectAccessReview

Source

const API_VERSION: &'static str = "authorization.k8s.io/v1"

Source

const GROUP: &'static str = "authorization.k8s.io"

Source

const KIND: &'static str = "LocalSubjectAccessReview"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "localsubjectaccessreviews"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for k8s_openapi::api::admissionregistration::v1::MutatingAdmissionPolicy

Source

const API_VERSION: &'static str = "admissionregistration.k8s.io/v1"

Source

const GROUP: &'static str = "admissionregistration.k8s.io"

Source

const KIND: &'static str = "MutatingAdmissionPolicy"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "mutatingadmissionpolicies"

Source

type Scope = ClusterResourceScope

Source

impl Resource for k8s_openapi::api::admissionregistration::v1alpha1::MutatingAdmissionPolicy

Source

const API_VERSION: &'static str = "admissionregistration.k8s.io/v1alpha1"

Source

const GROUP: &'static str = "admissionregistration.k8s.io"

Source

const KIND: &'static str = "MutatingAdmissionPolicy"

Source

const VERSION: &'static str = "v1alpha1"

Source

const URL_PATH_SEGMENT: &'static str = "mutatingadmissionpolicies"

Source

type Scope = ClusterResourceScope

Source

impl Resource for k8s_openapi::api::admissionregistration::v1beta1::MutatingAdmissionPolicy

Source

const API_VERSION: &'static str = "admissionregistration.k8s.io/v1beta1"

Source

const GROUP: &'static str = "admissionregistration.k8s.io"

Source

const KIND: &'static str = "MutatingAdmissionPolicy"

Source

const VERSION: &'static str = "v1beta1"

Source

const URL_PATH_SEGMENT: &'static str = "mutatingadmissionpolicies"

Source

type Scope = ClusterResourceScope

Source

impl Resource for k8s_openapi::api::admissionregistration::v1::MutatingAdmissionPolicyBinding

Source

const API_VERSION: &'static str = "admissionregistration.k8s.io/v1"

Source

const GROUP: &'static str = "admissionregistration.k8s.io"

Source

const KIND: &'static str = "MutatingAdmissionPolicyBinding"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "mutatingadmissionpolicybindings"

Source

type Scope = ClusterResourceScope

Source

impl Resource for k8s_openapi::api::admissionregistration::v1alpha1::MutatingAdmissionPolicyBinding

Source

const API_VERSION: &'static str = "admissionregistration.k8s.io/v1alpha1"

Source

const GROUP: &'static str = "admissionregistration.k8s.io"

Source

const KIND: &'static str = "MutatingAdmissionPolicyBinding"

Source

const VERSION: &'static str = "v1alpha1"

Source

const URL_PATH_SEGMENT: &'static str = "mutatingadmissionpolicybindings"

Source

type Scope = ClusterResourceScope

Source

impl Resource for k8s_openapi::api::admissionregistration::v1beta1::MutatingAdmissionPolicyBinding

Source

const API_VERSION: &'static str = "admissionregistration.k8s.io/v1beta1"

Source

const GROUP: &'static str = "admissionregistration.k8s.io"

Source

const KIND: &'static str = "MutatingAdmissionPolicyBinding"

Source

const VERSION: &'static str = "v1beta1"

Source

const URL_PATH_SEGMENT: &'static str = "mutatingadmissionpolicybindings"

Source

type Scope = ClusterResourceScope

Source

impl Resource for MutatingWebhookConfiguration

Source

const API_VERSION: &'static str = "admissionregistration.k8s.io/v1"

Source

const GROUP: &'static str = "admissionregistration.k8s.io"

Source

const KIND: &'static str = "MutatingWebhookConfiguration"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "mutatingwebhookconfigurations"

Source

type Scope = ClusterResourceScope

Source

impl Resource for Namespace

Source

const API_VERSION: &'static str = "v1"

Source

const GROUP: &'static str = ""

Source

const KIND: &'static str = "Namespace"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "namespaces"

Source

type Scope = ClusterResourceScope

Source

impl Resource for NetworkPolicy

Source

const API_VERSION: &'static str = "networking.k8s.io/v1"

Source

const GROUP: &'static str = "networking.k8s.io"

Source

const KIND: &'static str = "NetworkPolicy"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "networkpolicies"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for Node

Source

const API_VERSION: &'static str = "v1"

Source

const GROUP: &'static str = ""

Source

const KIND: &'static str = "Node"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "nodes"

Source

type Scope = ClusterResourceScope

Source

impl Resource for PersistentVolume

Source

const API_VERSION: &'static str = "v1"

Source

const GROUP: &'static str = ""

Source

const KIND: &'static str = "PersistentVolume"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "persistentvolumes"

Source

type Scope = ClusterResourceScope

Source

impl Resource for PersistentVolumeClaim

Source

const API_VERSION: &'static str = "v1"

Source

const GROUP: &'static str = ""

Source

const KIND: &'static str = "PersistentVolumeClaim"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "persistentvolumeclaims"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for Pod

Source

const API_VERSION: &'static str = "v1"

Source

const GROUP: &'static str = ""

Source

const KIND: &'static str = "Pod"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "pods"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for PodCertificateRequest

Source

const API_VERSION: &'static str = "certificates.k8s.io/v1beta1"

Source

const GROUP: &'static str = "certificates.k8s.io"

Source

const KIND: &'static str = "PodCertificateRequest"

Source

const VERSION: &'static str = "v1beta1"

Source

const URL_PATH_SEGMENT: &'static str = "podcertificaterequests"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for PodDisruptionBudget

Source

const API_VERSION: &'static str = "policy/v1"

Source

const GROUP: &'static str = "policy"

Source

const KIND: &'static str = "PodDisruptionBudget"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "poddisruptionbudgets"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for PodGroup

Source

const API_VERSION: &'static str = "scheduling.k8s.io/v1alpha2"

Source

const GROUP: &'static str = "scheduling.k8s.io"

Source

const KIND: &'static str = "PodGroup"

Source

const VERSION: &'static str = "v1alpha2"

Source

const URL_PATH_SEGMENT: &'static str = "podgroups"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for PodTemplate

Source

const API_VERSION: &'static str = "v1"

Source

const GROUP: &'static str = ""

Source

const KIND: &'static str = "PodTemplate"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "podtemplates"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for PriorityClass

Source

const API_VERSION: &'static str = "scheduling.k8s.io/v1"

Source

const GROUP: &'static str = "scheduling.k8s.io"

Source

const KIND: &'static str = "PriorityClass"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "priorityclasses"

Source

type Scope = ClusterResourceScope

Source

impl Resource for PriorityLevelConfiguration

Source

const API_VERSION: &'static str = "flowcontrol.apiserver.k8s.io/v1"

Source

const GROUP: &'static str = "flowcontrol.apiserver.k8s.io"

Source

const KIND: &'static str = "PriorityLevelConfiguration"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "prioritylevelconfigurations"

Source

type Scope = ClusterResourceScope

Source

impl Resource for ReplicaSet

Source

const API_VERSION: &'static str = "apps/v1"

Source

const GROUP: &'static str = "apps"

Source

const KIND: &'static str = "ReplicaSet"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "replicasets"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for ReplicationController

Source

const API_VERSION: &'static str = "v1"

Source

const GROUP: &'static str = ""

Source

const KIND: &'static str = "ReplicationController"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "replicationcontrollers"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for k8s_openapi::api::resource::v1::ResourceClaim

Source

const API_VERSION: &'static str = "resource.k8s.io/v1"

Source

const GROUP: &'static str = "resource.k8s.io"

Source

const KIND: &'static str = "ResourceClaim"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "resourceclaims"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for k8s_openapi::api::resource::v1beta1::ResourceClaim

Source

const API_VERSION: &'static str = "resource.k8s.io/v1beta1"

Source

const GROUP: &'static str = "resource.k8s.io"

Source

const KIND: &'static str = "ResourceClaim"

Source

const VERSION: &'static str = "v1beta1"

Source

const URL_PATH_SEGMENT: &'static str = "resourceclaims"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for k8s_openapi::api::resource::v1beta2::ResourceClaim

Source

const API_VERSION: &'static str = "resource.k8s.io/v1beta2"

Source

const GROUP: &'static str = "resource.k8s.io"

Source

const KIND: &'static str = "ResourceClaim"

Source

const VERSION: &'static str = "v1beta2"

Source

const URL_PATH_SEGMENT: &'static str = "resourceclaims"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for k8s_openapi::api::resource::v1::ResourceClaimTemplate

Source

const API_VERSION: &'static str = "resource.k8s.io/v1"

Source

const GROUP: &'static str = "resource.k8s.io"

Source

const KIND: &'static str = "ResourceClaimTemplate"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "resourceclaimtemplates"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for k8s_openapi::api::resource::v1beta1::ResourceClaimTemplate

Source

const API_VERSION: &'static str = "resource.k8s.io/v1beta1"

Source

const GROUP: &'static str = "resource.k8s.io"

Source

const KIND: &'static str = "ResourceClaimTemplate"

Source

const VERSION: &'static str = "v1beta1"

Source

const URL_PATH_SEGMENT: &'static str = "resourceclaimtemplates"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for k8s_openapi::api::resource::v1beta2::ResourceClaimTemplate

Source

const API_VERSION: &'static str = "resource.k8s.io/v1beta2"

Source

const GROUP: &'static str = "resource.k8s.io"

Source

const KIND: &'static str = "ResourceClaimTemplate"

Source

const VERSION: &'static str = "v1beta2"

Source

const URL_PATH_SEGMENT: &'static str = "resourceclaimtemplates"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for ResourcePoolStatusRequest

Source

const API_VERSION: &'static str = "resource.k8s.io/v1alpha3"

Source

const GROUP: &'static str = "resource.k8s.io"

Source

const KIND: &'static str = "ResourcePoolStatusRequest"

Source

const VERSION: &'static str = "v1alpha3"

Source

const URL_PATH_SEGMENT: &'static str = "resourcepoolstatusrequests"

Source

type Scope = ClusterResourceScope

Source

impl Resource for ResourceQuota

Source

const API_VERSION: &'static str = "v1"

Source

const GROUP: &'static str = ""

Source

const KIND: &'static str = "ResourceQuota"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "resourcequotas"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for k8s_openapi::api::resource::v1::ResourceSlice

Source

const API_VERSION: &'static str = "resource.k8s.io/v1"

Source

const GROUP: &'static str = "resource.k8s.io"

Source

const KIND: &'static str = "ResourceSlice"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "resourceslices"

Source

type Scope = ClusterResourceScope

Source

impl Resource for k8s_openapi::api::resource::v1beta1::ResourceSlice

Source

const API_VERSION: &'static str = "resource.k8s.io/v1beta1"

Source

const GROUP: &'static str = "resource.k8s.io"

Source

const KIND: &'static str = "ResourceSlice"

Source

const VERSION: &'static str = "v1beta1"

Source

const URL_PATH_SEGMENT: &'static str = "resourceslices"

Source

type Scope = ClusterResourceScope

Source

impl Resource for k8s_openapi::api::resource::v1beta2::ResourceSlice

Source

const API_VERSION: &'static str = "resource.k8s.io/v1beta2"

Source

const GROUP: &'static str = "resource.k8s.io"

Source

const KIND: &'static str = "ResourceSlice"

Source

const VERSION: &'static str = "v1beta2"

Source

const URL_PATH_SEGMENT: &'static str = "resourceslices"

Source

type Scope = ClusterResourceScope

Source

impl Resource for Role

Source

const API_VERSION: &'static str = "rbac.authorization.k8s.io/v1"

Source

const GROUP: &'static str = "rbac.authorization.k8s.io"

Source

const KIND: &'static str = "Role"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "roles"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for RoleBinding

Source

const API_VERSION: &'static str = "rbac.authorization.k8s.io/v1"

Source

const GROUP: &'static str = "rbac.authorization.k8s.io"

Source

const KIND: &'static str = "RoleBinding"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "rolebindings"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for RuntimeClass

Source

const API_VERSION: &'static str = "node.k8s.io/v1"

Source

const GROUP: &'static str = "node.k8s.io"

Source

const KIND: &'static str = "RuntimeClass"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "runtimeclasses"

Source

type Scope = ClusterResourceScope

Source

impl Resource for Scale

Source

const API_VERSION: &'static str = "autoscaling/v1"

Source

const GROUP: &'static str = "autoscaling"

Source

const KIND: &'static str = "Scale"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "scale"

Source

type Scope = SubResourceScope

Source

impl Resource for Secret

Source

const API_VERSION: &'static str = "v1"

Source

const GROUP: &'static str = ""

Source

const KIND: &'static str = "Secret"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "secrets"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for SelfSubjectAccessReview

Source

const API_VERSION: &'static str = "authorization.k8s.io/v1"

Source

const GROUP: &'static str = "authorization.k8s.io"

Source

const KIND: &'static str = "SelfSubjectAccessReview"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "selfsubjectaccessreviews"

Source

type Scope = ClusterResourceScope

Source

impl Resource for SelfSubjectReview

Source

const API_VERSION: &'static str = "authentication.k8s.io/v1"

Source

const GROUP: &'static str = "authentication.k8s.io"

Source

const KIND: &'static str = "SelfSubjectReview"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "selfsubjectreviews"

Source

type Scope = ClusterResourceScope

Source

impl Resource for SelfSubjectRulesReview

Source

const API_VERSION: &'static str = "authorization.k8s.io/v1"

Source

const GROUP: &'static str = "authorization.k8s.io"

Source

const KIND: &'static str = "SelfSubjectRulesReview"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "selfsubjectrulesreviews"

Source

type Scope = ClusterResourceScope

Source

impl Resource for Service

Source

const API_VERSION: &'static str = "v1"

Source

const GROUP: &'static str = ""

Source

const KIND: &'static str = "Service"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "services"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for ServiceAccount

Source

const API_VERSION: &'static str = "v1"

Source

const GROUP: &'static str = ""

Source

const KIND: &'static str = "ServiceAccount"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "serviceaccounts"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for k8s_openapi::api::networking::v1::ServiceCIDR

Source

const API_VERSION: &'static str = "networking.k8s.io/v1"

Source

const GROUP: &'static str = "networking.k8s.io"

Source

const KIND: &'static str = "ServiceCIDR"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "servicecidrs"

Source

type Scope = ClusterResourceScope

Source

impl Resource for k8s_openapi::api::networking::v1beta1::ServiceCIDR

Source

const API_VERSION: &'static str = "networking.k8s.io/v1beta1"

Source

const GROUP: &'static str = "networking.k8s.io"

Source

const KIND: &'static str = "ServiceCIDR"

Source

const VERSION: &'static str = "v1beta1"

Source

const URL_PATH_SEGMENT: &'static str = "servicecidrs"

Source

type Scope = ClusterResourceScope

Source

impl Resource for StatefulSet

Source

const API_VERSION: &'static str = "apps/v1"

Source

const GROUP: &'static str = "apps"

Source

const KIND: &'static str = "StatefulSet"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "statefulsets"

Source

type Scope = NamespaceResourceScope

Source

impl Resource for Status

Source

const API_VERSION: &'static str = "v1"

Source

const GROUP: &'static str = ""

Source

const KIND: &'static str = "Status"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "status"

Source

type Scope = SubResourceScope

Source

impl Resource for StorageClass

Source

const API_VERSION: &'static str = "storage.k8s.io/v1"

Source

const GROUP: &'static str = "storage.k8s.io"

Source

const KIND: &'static str = "StorageClass"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "storageclasses"

Source

type Scope = ClusterResourceScope

Source

impl Resource for StorageVersion

Source

const API_VERSION: &'static str = "internal.apiserver.k8s.io/v1alpha1"

Source

const GROUP: &'static str = "internal.apiserver.k8s.io"

Source

const KIND: &'static str = "StorageVersion"

Source

const VERSION: &'static str = "v1alpha1"

Source

const URL_PATH_SEGMENT: &'static str = "storageversions"

Source

type Scope = ClusterResourceScope

Source

impl Resource for StorageVersionMigration

Source

const API_VERSION: &'static str = "storagemigration.k8s.io/v1beta1"

Source

const GROUP: &'static str = "storagemigration.k8s.io"

Source

const KIND: &'static str = "StorageVersionMigration"

Source

const VERSION: &'static str = "v1beta1"

Source

const URL_PATH_SEGMENT: &'static str = "storageversionmigrations"

Source

type Scope = ClusterResourceScope

Source

impl Resource for SubjectAccessReview

Source

const API_VERSION: &'static str = "authorization.k8s.io/v1"

Source

const GROUP: &'static str = "authorization.k8s.io"

Source

const KIND: &'static str = "SubjectAccessReview"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "subjectaccessreviews"

Source

type Scope = ClusterResourceScope

Source

impl Resource for TokenRequest

Source

const API_VERSION: &'static str = "authentication.k8s.io/v1"

Source

const GROUP: &'static str = "authentication.k8s.io"

Source

const KIND: &'static str = "TokenRequest"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "token"

Source

type Scope = SubResourceScope

Source

impl Resource for TokenReview

Source

const API_VERSION: &'static str = "authentication.k8s.io/v1"

Source

const GROUP: &'static str = "authentication.k8s.io"

Source

const KIND: &'static str = "TokenReview"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "tokenreviews"

Source

type Scope = ClusterResourceScope

Source

impl Resource for ValidatingAdmissionPolicy

Source

const API_VERSION: &'static str = "admissionregistration.k8s.io/v1"

Source

const GROUP: &'static str = "admissionregistration.k8s.io"

Source

const KIND: &'static str = "ValidatingAdmissionPolicy"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "validatingadmissionpolicies"

Source

type Scope = ClusterResourceScope

Source

impl Resource for ValidatingAdmissionPolicyBinding

Source

const API_VERSION: &'static str = "admissionregistration.k8s.io/v1"

Source

const GROUP: &'static str = "admissionregistration.k8s.io"

Source

const KIND: &'static str = "ValidatingAdmissionPolicyBinding"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "validatingadmissionpolicybindings"

Source

type Scope = ClusterResourceScope

Source

impl Resource for ValidatingWebhookConfiguration

Source

const API_VERSION: &'static str = "admissionregistration.k8s.io/v1"

Source

const GROUP: &'static str = "admissionregistration.k8s.io"

Source

const KIND: &'static str = "ValidatingWebhookConfiguration"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "validatingwebhookconfigurations"

Source

type Scope = ClusterResourceScope

Source

impl Resource for VolumeAttachment

Source

const API_VERSION: &'static str = "storage.k8s.io/v1"

Source

const GROUP: &'static str = "storage.k8s.io"

Source

const KIND: &'static str = "VolumeAttachment"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "volumeattachments"

Source

type Scope = ClusterResourceScope

Source

impl Resource for k8s_openapi::api::storage::v1::VolumeAttributesClass

Source

const API_VERSION: &'static str = "storage.k8s.io/v1"

Source

const GROUP: &'static str = "storage.k8s.io"

Source

const KIND: &'static str = "VolumeAttributesClass"

Source

const VERSION: &'static str = "v1"

Source

const URL_PATH_SEGMENT: &'static str = "volumeattributesclasses"

Source

type Scope = ClusterResourceScope

Source

impl Resource for k8s_openapi::api::storage::v1beta1::VolumeAttributesClass

Source

const API_VERSION: &'static str = "storage.k8s.io/v1beta1"

Source

const GROUP: &'static str = "storage.k8s.io"

Source

const KIND: &'static str = "VolumeAttributesClass"

Source

const VERSION: &'static str = "v1beta1"

Source

const URL_PATH_SEGMENT: &'static str = "volumeattributesclasses"

Source

type Scope = ClusterResourceScope

Source

impl Resource for Workload

Source

const API_VERSION: &'static str = "scheduling.k8s.io/v1alpha2"

Source

const GROUP: &'static str = "scheduling.k8s.io"

Source

const KIND: &'static str = "Workload"

Source

const VERSION: &'static str = "v1alpha2"

Source

const URL_PATH_SEGMENT: &'static str = "workloads"

Source

type Scope = NamespaceResourceScope

Source

impl<T> Resource for List<T>

Source

const API_VERSION: &'static str = <T as crate::Resource>::API_VERSION

Source

const GROUP: &'static str = <T as crate::Resource>::GROUP

Source

const KIND: &'static str = <T as crate::ListableResource>::LIST_KIND

Source

const VERSION: &'static str = <T as crate::Resource>::VERSION

Source

const URL_PATH_SEGMENT: &'static str = ""

Source

type Scope = <T as Resource>::Scope